@@ -1,7 +1,8 @@
 from mltraq.options import options
 from mltraq.run import Run, Runs
 from mltraq.session import Session as create_session
+from mltraq.session import experiment
 from mltraq.utils.sequence import Sequence
 from mltraq.version import __version__
 
-__all__ = ("create_session", "Run", "Runs", "Sequence", "options", "__version__")
+__all__ = ("create_session", "experiment", "Run", "Runs", "Sequence", "options", "__version__")
