@@ -5,6 +5,7 @@ import time
 from typing import Callable, Dict, Optional
 
 from colorama import Back, Fore, Style
+from mltraq.extras.environment import is_tty
 from mltraq.options import options
 
 logger = logging.getLogger("mltraq")
@@ -44,31 +45,33 @@ class ColoredFormatter(logging.Formatter):
 def init_logging():
     """Logging intialization."""
 
-    if options.get("logging.clear_handlers_default_logger"):
-        logging.getLogger().handlers.clear()
-
     # Get logger for MLTRAQ and clear the handlers.
     logger = logging.getLogger("mltraq")
     logger.handlers.clear()
     logger.setLevel(getattr(logging, options.get("logging.level")))
 
     if options.get("logging.stdout"):
-        # we drop the default logger to stdout, to avoid duplicate output.
-        # default_logger = logging.getLogger()
-        # default_logger.handlers.clear()
+        if is_tty():
+            formatter = ColoredFormatter(
+                "{color}■{reset} {message}",
+                style="{",
+                datefmt="%Y-%m-%d %H:%M:%S",
+                colors={
+                    "DEBUG": Fore.CYAN,
+                    "INFO": Fore.GREEN,
+                    "WARNING": Fore.YELLOW,
+                    "ERROR": Fore.RED,
+                    "CRITICAL": Fore.RED + Back.WHITE + Style.BRIGHT,
+                },
+            )
 
-        formatter = ColoredFormatter(
-            "{color}■{reset} {message}",
-            style="{",
-            datefmt="%Y-%m-%d %H:%M:%S",
-            colors={
-                "DEBUG": Fore.CYAN,
-                "INFO": Fore.GREEN,
-                "WARNING": Fore.YELLOW,
-                "ERROR": Fore.RED,
-                "CRITICAL": Fore.RED + Back.WHITE + Style.BRIGHT,
-            },
-        )
+        else:
+            formatter = logging.Formatter("[%(levelname)s] %(message)s")
+
+        if options.get("logging.clear_handlers_default_logger"):
+            # Drop other default handlers, otherwise we might end up with
+            # duplicate log entries to stdout.
+            logging.getLogger().handlers.clear()
 
         handler = logging.StreamHandler(sys.stdout)
         handler.setFormatter(formatter)
